@@ -31,6 +31,7 @@ our @EXPORT = qw(
 
     first_line_like
     build_ack_invocation
+    adjust_executable
 
     read_file
     write_file
@@ -402,15 +403,7 @@ sub get_rc {
 sub run_ack_with_stderr {
     my @args = @_;
 
-    my $perl = caret_X();
-
-    @args = build_ack_invocation( @args );
-    if ( $ENV{'ACK_TEST_STANDALONE'} ) {
-        unshift( @args, $perl );
-    }
-    else {
-        unshift( @args, $perl, "-Mblib=$orig_wd" );
-    }
+    @args = adjust_executable( build_ack_invocation( @args ) );
 
     return run_cmd( @args );
 }
@@ -748,6 +741,9 @@ BEGIN {
 
     if ($has_io_pty) {
         no strict 'refs';
+        # This function fools ack into thinking it is not writing to a pipe. This lets us test some of ack's default
+        # behaviors, like defaulting to --break/--heading in interactive mode, but --nobreak/--noheading when writing
+        # to a pipe.
         *run_ack_interactive = sub {
             my ( @args) = @_;
 
@@ -756,6 +752,8 @@ BEGIN {
 
             _record_option_coverage(@cmd);
 
+            @cmd = adjust_executable( @cmd );
+
             my $pty = IO::Pty->new;
 
             my $pid = fork;
@@ -801,15 +799,6 @@ BEGIN {
 
                 close $slave;
 
-                my $perl = caret_X();
-
-                if ( $ENV{'ACK_TEST_STANDALONE'} ) {
-                    unshift( @cmd, $perl );
-                }
-                else {
-                    unshift( @cmd, $perl, "-Mblib=$orig_wd" );
-                }
-
                 exec @cmd;
             }
         };
@@ -1227,4 +1216,20 @@ sub make_unreadable {
 }
 
 
+sub adjust_executable {
+    my @cmd = @_;
+
+    my $perl = caret_X();
+
+    if ( $ENV{'ACK_TEST_STANDALONE'} ) {
+        unshift( @cmd, $perl );
+    }
+    else {
+        unshift( @cmd, $perl, "-Mblib=$orig_wd" );
+    }
+
+    return @cmd;
+}
+
+
 1;
